==> apache-dolphinscheduler-2.0.6-src.tar.gz: apache-dolphinscheduler-2.0.6-src/dolphinscheduler-common/src/main/java/org/apache/dolphinscheduler/common/task/switchtask/SwitchResultVo.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.dolphinscheduler.common.task.switchtask;

import java.util.ArrayList;
import java.util.List;

public class SwitchResultVo {

    private String condition;
    private List<String> nextNode;

    public String getCondition() {
        return condition;
    }

    public void setCondition(String condition) {
        this.condition = condition;
    }

    public List<String> getNextNode() {
        return nextNode;
    }

    public void setNextNode(Object nextNode) {
        if (nextNode instanceof String) {
            List<String> nextNodeList = new ArrayList<>();
            nextNodeList.add(String.valueOf(nextNode));
            this.nextNode = nextNodeList;
        } else if (nextNode instanceof Number) {
            List<String> nextNodeList = new ArrayList<>();
            nextNodeList.add(nextNode.toString());
            this.nextNode = nextNodeList;
        } else {
            this.nextNode = (ArrayList) nextNode;
        }
    }
}

==> apache-dolphinscheduler-2.0.9-src.tar.gz: apache-dolphinscheduler-2.0.9-src/dolphinscheduler-common/src/main/java/org/apache/dolphinscheduler/common/task/switchtask/SwitchResultVo.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.dolphinscheduler.common.task.switchtask;

import org.apache.commons.collections.CollectionUtils;

import java.util.ArrayList;
import java.util.List;

public class SwitchResultVo {

    private String condition;
    private Long nextNode;

    public String getCondition() {
        return condition;
    }

    public void setCondition(String condition) {
        this.condition = condition;
    }

    public Long getNextNode() {
        return nextNode;
    }

    public void setNextNode(Object nextNode) {
        if (nextNode instanceof Long) {
            this.nextNode = (Long) nextNode;
        } else {
            List<String> nextNodes = (ArrayList) nextNode;
            if (CollectionUtils.isNotEmpty(nextNodes)) {
                this.nextNode = Long.parseLong(nextNodes.get(0));
            }
        }
    }
}
